@@ -1,20 +1,23 @@
 #ifndef NETWORK_H
 #define NETWORK_H
 
+/**
+ * \file network.h
+ * \brief network related functions
+ */
+
 #include "link.h"
 
-#define NETWORK_MAX_CONNS 20
-
-typedef struct {
-    char *memory;
-    size_t size;
-} MemoryStruct;
-
 typedef enum {
     FILESTAT = 's',
     DATA = 'd'
 } TransferType;
 
+typedef struct {
+    char *memory;
+    size_t size;
+} MemoryStruct;
+
 typedef struct {
     TransferType type;
     int transferring;
@@ -28,8 +31,25 @@ typedef struct {
     char *proxy_user;
     char *proxy_pass;
     long max_conns;
+    char *user_agent;
+    int http_429_wait;
+    char *cache_dir;
+    int cache_enabled;
 } NetworkConfigStruct;
 
+/** \brief HTTP response codes */
+typedef enum {
+    HTTP_OK                         = 200,
+    HTTP_PARTIAL_CONTENT            = 206,
+    HTTP_RANGE_NOT_SATISFIABLE      = 416,
+    HTTP_TOO_MANY_REQUESTS          = 429,
+    HTTP_CLOUDFLARE_UNKNOWN_ERROR   = 520,
+    HTTP_CLOUDFLARE_TIMEOUT         = 524
+} HTTPResponseCode;
+
+/** \brief The waiting time after getting HTTP 429 */
+extern int HTTP_WAIT_SEC;
+
 /** \brief CURL configuration */
 extern NetworkConfigStruct NETWORK_CONFIG;
 
@@ -55,4 +75,9 @@ void transfer_nonblocking(CURL *curl);
 size_t
 write_memory_callback(void *contents, size_t size, size_t nmemb, void *userp);
 
+/**
+ * \brief check if a HTTP response code corresponds to a temporary failure
+ */
+int HTTP_temp_failure(HTTPResponseCode http_resp);
+
 #endif
